# arpes.analysis package

## Submodules

  - [arpes.analysis.align module](arpes.analysis.align)
  - [arpes.analysis.band\_analysis module](arpes.analysis.band_analysis)
  - [arpes.analysis.band\_analysis\_utils
    module](arpes.analysis.band_analysis_utils)
  - [arpes.analysis.decomposition module](arpes.analysis.decomposition)
  - [arpes.analysis.deconvolution module](arpes.analysis.deconvolution)
  - [arpes.analysis.derivative module](arpes.analysis.derivative)
  - [arpes.analysis.fft module](arpes.analysis.fft)
  - [arpes.analysis.filters module](arpes.analysis.filters)
  - [arpes.analysis.fs module](arpes.analysis.fs)
  - [arpes.analysis.gap module](arpes.analysis.gap)
  - [arpes.analysis.general module](arpes.analysis.general)
  - [arpes.analysis.kfermi module](arpes.analysis.kfermi)
  - [arpes.analysis.mask module](arpes.analysis.mask)
  - [arpes.analysis.moire module](arpes.analysis.moire)
  - [arpes.analysis.path module](arpes.analysis.path)
  - [arpes.analysis.pocket module](arpes.analysis.pocket)
  - [arpes.analysis.resolution module](arpes.analysis.resolution)
  - [arpes.analysis.sarpes module](arpes.analysis.sarpes)
  - [arpes.analysis.savitzky\_golay
    module](arpes.analysis.savitzky_golay)
  - [arpes.analysis.self\_energy module](arpes.analysis.self_energy)
  - [arpes.analysis.shirley module](arpes.analysis.shirley)
  - [arpes.analysis.statistics module](arpes.analysis.statistics)
  - [arpes.analysis.tarpes module](arpes.analysis.tarpes)
  - [arpes.analysis.xps module](arpes.analysis.xps)

## Module contents
